==> nextcloud-21.0.5.tgz: nextcloud/apps/privacy/l10n/zh_TW.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "隱私",
    "-" : "－",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "隱私中心會顯示您的資料儲存在哪裡，以及誰可以存取它，這可能是因為您與他們分享或是他們是管理員。",
    "Remove external admin" : "移除外部管理員",
    "Add external admin" : "新增外部管理員",
    "Name of external admin" : "外部管理員名稱",
    "This server is using full-disk-encryption." : "此伺服器使用了全磁碟加密。",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "您的主要儲存空間使用有主控金鑰的{linkopen}伺服器端加密 ↗{linkclose}加密了。",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "您在外部儲存空間的檔案根據其設定可以使用有主控金鑰的{linkopen}伺服器端加密 ↗{linkclose}來加密。",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "使用{linkopen}伺服器端加密 ↗{linkclose}與個別的使用者金鑰來對您的主要儲存空間加密。",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "您在外部儲存空間的檔案根據其設定可以使用有單獨金鑰的{linkopen}伺服器端加密 ↗{linkclose}來加密。",
    "Additionally, this server is protected with full-disk-encryption." : "此外，此伺服器也受到全磁碟加密的保護。",
    "This server is protected with full-disk-encryption." : "此伺服器已由全磁碟加密保護。",
    "Your files are not protected by encryption." : "您的檔案並未受加密保護。",
    "Your data is located in:" : "您的資料位於：",
    "The admin hasn't selected the location of the server yet." : "管理員尚未選取伺服器的位置。",
    "Change data location" : "變更資料位置",
    "Please select a region" : "請選取區域",
    "You don't have any shares with individual users." : "您沒有與個人使用者分享的任何內容。",
    "Somaliland" : "索馬利蘭",
    "Andorra" : "安道爾",
    "United Arab Emirates" : "阿拉伯聯合大公國",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安地卡及巴布達",
    "Anguilla" : "安吉拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極洲",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳洲",
    "Aruba" : "阿魯巴",
    "Åland Islands" : "奧蘭群島",
    "Azerbaijan" : "亞塞拜然",
    "Bosnia and Herzegovina" : "波士尼亞與赫塞哥維納",
    "Barbados" : "巴貝多",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "布吉納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "蒲隆地",
    "Benin" : "貝南",
    "Saint Barthélemy" : "聖巴瑟米",
    "Bermuda" : "百慕達",
    "Brunei" : "汶萊",
    "Bolivia" : "玻利維亞",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布威島",
    "Botswana" : "波札那",
    "Belarus" : "白俄羅斯",
    "Belize" : "貝里斯",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯（基林）群島",
    "Democratic Republic of the Congo" : "剛果民主共和國",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果",
    "Switzerland" : "瑞士",
    "Cote d'Ivoire" : "象牙海岸共和國",
    "Cook Islands" : "庫克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯大黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "維德角",
    "Curaçao" : "古拉索",
    "Christmas Island" : "聖誕島",
    "Cyprus" : "賽普勒斯",
    "Czech" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布地",
    "Denmark" : "丹麥",
    "Dominican Republic" : "多明尼加",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "West Sahara" : "西撒哈拉",
    "Eritrea" : "厄利垂亞",
    "Spain" : "西班牙",
    "Ethiopia" : "衣索比亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands" : "福克蘭群島",
    "Micronesia" : "密克羅尼西亞",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加彭",
    "United Kingdom" : "聯合王國",
    "Grenada" : "格瑞那達",
    "Georgia" : "喬治亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根西",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "甘比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜地洛普",
    "Equatorial Guinea" : "赤道幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞與南桑威奇群島",
    "Guatemala" : "瓜地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比索",
    "Guyana" : "蓋亞那",
    "Honduras" : "宏都拉斯",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Croatia" : "克羅埃西亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "曼島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋屬地",
    "Iraq" : "伊拉克",
    "Iran" : "伊朗",
    "Iceland" : "冰島",
    "Italy" : "義大利",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "吉里巴斯",
    "Comores" : "葛摩",
    "Saint Kitts and Nevis" : "聖克里斯多福及尼維斯",
    "North Korea" : "朝鮮民主主義人民共和國",
    "South Korea" : "大韓民國",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Laos" : "寮國",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦斯登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "賴比瑞亞",
    "Lesotho" : "賴索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Moldova" : "摩爾多瓦",
    "Montenegro" : "蒙特內哥羅",
    "Saint Martin" : "聖馬丁",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "Macedonia" : "馬其頓",
    "Mali" : "馬利",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬里亞納群島",
    "Mauritania" : "茅利塔尼亞",
    "Montserrat" : "蒙哲臘",
    "Malta" : "馬爾他",
    "Mauritius" : "模里西斯",
    "Maldives" : "馬爾地夫",
    "Malawi" : "馬拉威",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫三比克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "奈及利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "諾魯",
    "Niue" : "紐埃",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬玻里尼西亞",
    "Papua New Guinea" : "巴布亞紐幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮耶與密克隆群島",
    "Pitcairn" : "皮特肯群島",
    "Puerto Rico" : "波多黎各",
    "Palestine" : "巴勒斯坦",
    "Portugal" : "葡萄牙",
    "Palau" : "帛琉",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡達",
    "Réunion" : "留尼旺",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russia" : "俄羅斯",
    "Rwanda" : "盧安達",
    "Saudi Arabia" : "沙烏地阿拉伯",
    "Solomon Islands" : " 索羅門群島",
    "Seychelles" : "塞席爾",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿、亞森欣與崔斯坦達庫尼亞",
    "Slovenia" : "斯洛維尼亞",
    "Svalbard and Jan Mayen" : "斯瓦巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "獅子山共和國",
    "San Marino" : "聖馬利諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬利亞",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten" : "荷屬聖馬丁",
    "Syria" : "敘利亞",
    "Swaziland" : "史瓦帝尼",
    "Turks and Caicos Islands" : "土克凱可群島",
    "Chad" : "查德",
    "Fr. S. Antarctic Lands" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克",
    "Tokelau" : "托克勞",
    "Timor-Leste" : "東帝汶",
    "Turkmenistan" : "土庫曼",
    "Tunisia" : "突尼西亞",
    "Tonga" : "東加",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "千里達及托巴哥",
    "Tuvalu" : "吐瓦魯",
    "Taiwan" : "台灣",
    "Tanzania" : "坦尚尼亞",
    "Ukraine" : "烏克蘭",
    "Uganda" : "烏干達",
    "United States Minor Outlying Islands" : "美國本土外小島嶼",
    "United States" : "美國",
    "Uruguay" : "烏拉圭",
    "Uzbekistan" : "烏茲別克",
    "Holy See" : "聖座",
    "Saint Vincent and the Grenadines" : "聖文森及格瑞那丁",
    "Venezuela" : "委內瑞拉",
    "Virgin Islands (British)" : "英屬維京群島",
    "Virgin Islands (U.S.)" : "美屬維京群島",
    "Vietnam" : "越南",
    "Vanuatu" : "萬那杜",
    "Wallis and Futuna" : "瓦利斯和富圖那",
    "Samoa" : "薩摩亞",
    "Yemen" : "葉門",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Zambia" : "尚比亞",
    "Zimbabwe" : "辛巴威",
    "Your Nextcloud account" : "您的 Nextcloud 帳號",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "您的資料就是您自己，在網路上很容易被濫用。在 Nextcloud，我們相信您有權決定您要如何使用您的資料。Nextcloud 會根據使用者資料宣言來保護您的權利！",
    "User Data Manifesto 2.0" : "使用者資料宣言 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "定義網際網路時代，人們控制自己的資料的基本權利",
    "Control" : "控制",
    "over user data access" : "使用者資料存取",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "使用者自願將特定的資料上傳，他就應該有完全的掌控權。使用者應該可以決定誰能被授權存取資料，而且此授權的權限及規則也由使用者涋定。",
    "Knowledge" : "知識",
    "of how the data is stored" : "資料儲存方式",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "當資料被上傳到特定的服務提供商時，使用者應該要被告知特定的服務提供商將資料儲存在何處，該服務提供商營運多久，在哪個國家的管轄範圍內營運，以及適用何處的法律。",
    "Freedom" : "自由",
    "to choose a platform" : "選擇平台",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "使用者應該要隨時可以從服務提供者處拿回其資料，而不會遇到任何被綁在特定供應商的狀況。格式與協定的開放標準是保證這一點的必要條件。",
    "Learn more ↗" : "取得更多資訊 ↗",
    "Where is your data?" : "您的資料在哪裡？",
    "Who has access to your data?" : "誰有權存取您的資料？",
    "Administrators" : "管理員",
    "People you shared with" : "與您分享的人",
    "Privacy policy" : "隱私權政策",
    "Read the privacy policy." : "閱讀隱私權政策",
    "Encryption" : "加密",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "您的檔案已使用{linkopen}伺服器端加密 ↗{linkclose}來加密。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "您的檔案已使用{linkopen}伺服器端加密 ↗{linkclose}來加密。此外，此伺服器已由全磁碟加密保護。",
    "Your data is located in: " : "您的資料位於："
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.3.tgz: nextcloud/apps/privacy/l10n/zh_TW.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "隱私",
    "-" : "－",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "隱私中心會顯示您的資料儲存在哪裡，以及誰可以存取它，這可能是因為您與他們分享或是他們是管理員。",
    "Remove external admin" : "移除外部管理員",
    "Add external admin" : "新增外部管理員",
    "Name of external admin" : "外部管理員名稱",
    "This server is using full-disk-encryption." : "此伺服器使用了全磁碟加密。",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "您的主要儲存空間使用有主控金鑰的{linkopen}伺服器端加密 ↗{linkclose}加密了。",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "您在外部儲存空間的檔案根據其設定可以使用有主控金鑰的{linkopen}伺服器端加密 ↗{linkclose}來加密。",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "使用{linkopen}伺服器端加密 ↗{linkclose}與個別的使用者金鑰來對您的主要儲存空間加密。",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "您在外部儲存空間的檔案根據其設定可以使用有單獨金鑰的{linkopen}伺服器端加密 ↗{linkclose}來加密。",
    "Additionally, this server is protected with full-disk-encryption." : "此外，此伺服器也受到全磁碟加密的保護。",
    "This server is protected with full-disk-encryption." : "此伺服器已由全磁碟加密保護。",
    "Your files are not protected by encryption." : "您的檔案並未受加密保護。",
    "Your data is located in:" : "您的資料位於：",
    "The admin has not selected the location of the server yet." : "管理員尚未選取伺服器所在位置。",
    "Change data location" : "變更資料位置",
    "Please select a region" : "請選取區域",
    "You don't have any shares with individual users." : "您沒有與個人使用者分享的任何內容。",
    "Somaliland" : "索馬利蘭",
    "Andorra" : "安道爾",
    "United Arab Emirates" : "阿拉伯聯合大公國",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安地卡及巴布達",
    "Anguilla" : "安吉拉",
    "Albania" : "阿爾巴尼亞",
    "Armenia" : "亞美尼亞",
    "Angola" : "安哥拉",
    "Antarctica" : "南極洲",
    "Argentina" : "阿根廷",
    "American Samoa" : "美屬薩摩亞",
    "Austria" : "奧地利",
    "Australia" : "澳洲",
    "Aruba" : "阿魯巴",
    "Åland Islands" : "奧蘭群島",
    "Azerbaijan" : "亞塞拜然",
    "Bosnia and Herzegovina" : "波士尼亞與赫塞哥維納",
    "Barbados" : "巴貝多",
    "Bangladesh" : "孟加拉",
    "Belgium" : "比利時",
    "Burkina Faso" : "布吉納法索",
    "Bulgaria" : "保加利亞",
    "Bahrain" : "巴林",
    "Burundi" : "蒲隆地",
    "Benin" : "貝南",
    "Saint Barthélemy" : "聖巴瑟米",
    "Bermuda" : "百慕達",
    "Brunei" : "汶萊",
    "Bolivia" : "玻利維亞",
    "Bonaire, Sint Eustatius and Saba" : "荷蘭加勒比區",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈馬",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布威島",
    "Botswana" : "波札那",
    "Belarus" : "白俄羅斯",
    "Belize" : "貝里斯",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯（基林）群島",
    "Democratic Republic of the Congo" : "剛果民主共和國",
    "Central African Republic" : "中非共和國",
    "Congo" : "剛果",
    "Switzerland" : "瑞士",
    "Cote d'Ivoire" : "象牙海岸共和國",
    "Cook Islands" : "庫克群島",
    "Chile" : "智利",
    "Cameroon" : "喀麥隆",
    "China" : "中國",
    "Colombia" : "哥倫比亞",
    "Costa Rica" : "哥斯大黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "維德角",
    "Curaçao" : "古拉索",
    "Christmas Island" : "聖誕島",
    "Cyprus" : "賽普勒斯",
    "Czech" : "捷克",
    "Germany" : "德國",
    "Djibouti" : "吉布地",
    "Denmark" : "丹麥",
    "Dominican Republic" : "多明尼加",
    "Algeria" : "阿爾及利亞",
    "Ecuador" : "厄瓜多",
    "Estonia" : "愛沙尼亞",
    "Egypt" : "埃及",
    "West Sahara" : "西撒哈拉",
    "Eritrea" : "厄利垂亞",
    "Spain" : "西班牙",
    "Ethiopia" : "衣索比亞",
    "Finland" : "芬蘭",
    "Fiji" : "斐濟",
    "Falkland Islands" : "福克蘭群島",
    "Micronesia" : "密克羅尼西亞",
    "Faroe Islands" : "法羅群島",
    "France" : "法國",
    "Gabon" : "加彭",
    "United Kingdom" : "聯合王國",
    "Grenada" : "格瑞那達",
    "Georgia" : "喬治亞",
    "French Guiana" : "法屬圭亞那",
    "Guernsey" : "根西",
    "Ghana" : "迦納",
    "Gibraltar" : "直布羅陀",
    "Greenland" : "格陵蘭",
    "Gambia" : "甘比亞",
    "Guinea" : "幾內亞",
    "Guadeloupe" : "瓜地洛普",
    "Equatorial Guinea" : "赤道幾內亞",
    "Greece" : "希臘",
    "South Georgia and the South Sandwich Islands" : "南喬治亞與南桑威奇群島",
    "Guatemala" : "瓜地馬拉",
    "Guam" : "關島",
    "Guinea-Bissau" : "幾內亞比索",
    "Guyana" : "蓋亞那",
    "Honduras" : "宏都拉斯",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德島和麥克唐納群島",
    "Croatia" : "克羅埃西亞",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印尼",
    "Ireland" : "愛爾蘭",
    "Israel" : "以色列",
    "Isle of Man" : "曼島",
    "India" : "印度",
    "British Indian Ocean Territory" : "英屬印度洋屬地",
    "Iraq" : "伊拉克",
    "Iran" : "伊朗",
    "Iceland" : "冰島",
    "Italy" : "義大利",
    "Jamaica" : "牙買加",
    "Jordan" : "約旦",
    "Japan" : "日本",
    "Kenya" : "肯亞",
    "Kyrgyzstan" : "吉爾吉斯",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "吉里巴斯",
    "Comores" : "葛摩",
    "Saint Kitts and Nevis" : "聖克里斯多福及尼維斯",
    "North Korea" : "朝鮮民主主義人民共和國",
    "South Korea" : "大韓民國",
    "Kuwait" : "科威特",
    "Cayman Islands" : "開曼群島",
    "Kazakhstan" : "哈薩克",
    "Laos" : "寮國",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "聖露西亞",
    "Liechtenstein" : "列支敦斯登",
    "Sri Lanka" : "斯里蘭卡",
    "Liberia" : "賴比瑞亞",
    "Lesotho" : "賴索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "盧森堡",
    "Latvia" : "拉脫維亞",
    "Libya" : "利比亞",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩納哥",
    "Moldova" : "摩爾多瓦",
    "Montenegro" : "蒙特內哥羅",
    "Saint Martin" : "聖馬丁",
    "Madagascar" : "馬達加斯加",
    "Marshall Islands" : "馬紹爾群島",
    "Macedonia" : "馬其頓",
    "Mali" : "馬利",
    "Myanmar" : "緬甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳門",
    "Northern Mariana Islands" : "北馬里亞納群島",
    "Mauritania" : "茅利塔尼亞",
    "Montserrat" : "蒙哲臘",
    "Malta" : "馬爾他",
    "Mauritius" : "模里西斯",
    "Maldives" : "馬爾地夫",
    "Malawi" : "馬拉威",
    "Mexico" : "墨西哥",
    "Malaysia" : "馬來西亞",
    "Mozambique" : "莫三比克",
    "Namibia" : "納米比亞",
    "New Caledonia" : "新喀里多尼亞",
    "Niger" : "尼日",
    "Norfolk Island" : "諾福克島",
    "Nigeria" : "奈及利亞",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷蘭",
    "Norway" : "挪威",
    "Nepal" : "尼泊爾",
    "Nauru" : "諾魯",
    "Niue" : "紐埃",
    "New Zealand" : "紐西蘭",
    "Oman" : "阿曼",
    "Panama" : "巴拿馬",
    "Peru" : "秘魯",
    "French Polynesia" : "法屬玻里尼西亞",
    "Papua New Guinea" : "巴布亞紐幾內亞",
    "Philippines" : "菲律賓",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波蘭",
    "Saint Pierre and Miquelon" : "聖皮耶與密克隆群島",
    "Pitcairn" : "皮特肯群島",
    "Puerto Rico" : "波多黎各",
    "Palestine" : "巴勒斯坦",
    "Portugal" : "葡萄牙",
    "Palau" : "帛琉",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡達",
    "Réunion" : "留尼旺",
    "Romania" : "羅馬尼亞",
    "Serbia" : "塞爾維亞",
    "Russia" : "俄羅斯",
    "Rwanda" : "盧安達",
    "Saudi Arabia" : "沙烏地阿拉伯",
    "Solomon Islands" : " 索羅門群島",
    "Seychelles" : "塞席爾",
    "Sudan" : "蘇丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "聖赫勒拿、亞森欣與崔斯坦達庫尼亞",
    "Slovenia" : "斯洛維尼亞",
    "Svalbard and Jan Mayen" : "斯瓦巴和揚馬延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "獅子山共和國",
    "San Marino" : "聖馬利諾",
    "Senegal" : "塞內加爾",
    "Somalia" : "索馬利亞",
    "Suriname" : "蘇利南",
    "South Sudan" : "南蘇丹",
    "Sao Tome and Principe" : "聖多美普林西比",
    "El Salvador" : "薩爾瓦多",
    "Sint Maarten" : "荷屬聖馬丁",
    "Syria" : "敘利亞",
    "Swaziland" : "史瓦帝尼",
    "Turks and Caicos Islands" : "土克凱可群島",
    "Chad" : "查德",
    "Fr. S. Antarctic Lands" : "法屬南部和南極領地",
    "Togo" : "多哥",
    "Thailand" : "泰國",
    "Tajikistan" : "塔吉克",
    "Tokelau" : "托克勞",
    "Timor-Leste" : "東帝汶",
    "Turkmenistan" : "土庫曼",
    "Tunisia" : "突尼西亞",
    "Tonga" : "東加",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "千里達及托巴哥",
    "Tuvalu" : "吐瓦魯",
    "Taiwan" : "台灣",
    "Tanzania" : "坦尚尼亞",
    "Ukraine" : "烏克蘭",
    "Uganda" : "烏干達",
    "United States Minor Outlying Islands" : "美國本土外小島嶼",
    "United States" : "美國",
    "Uruguay" : "烏拉圭",
    "Uzbekistan" : "烏茲別克",
    "Holy See" : "聖座",
    "Saint Vincent and the Grenadines" : "聖文森及格瑞那丁",
    "Venezuela" : "委內瑞拉",
    "Virgin Islands (British)" : "英屬維京群島",
    "Virgin Islands (U.S.)" : "美屬維京群島",
    "Vietnam" : "越南",
    "Vanuatu" : "萬那杜",
    "Wallis and Futuna" : "瓦利斯和富圖那",
    "Samoa" : "薩摩亞",
    "Yemen" : "葉門",
    "Mayotte" : "馬約特",
    "South Africa" : "南非",
    "Zambia" : "尚比亞",
    "Zimbabwe" : "辛巴威",
    "Your %s account" : "您的 %s 帳號",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "您的資料就是您自己，在網路上很容易被濫用。在 Nextcloud，我們相信您有權決定您要如何使用您的資料。Nextcloud 會根據使用者資料宣言來保護您的權利！",
    "User Data Manifesto 2.0" : "使用者資料宣言 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "定義網際網路時代，人們控制自己的資料的基本權利",
    "Control" : "控制",
    "over user data access" : "使用者資料存取",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "使用者自願將特定的資料上傳，他就應該有完全的掌控權。使用者應該可以決定誰能被授權存取資料，而且此授權的權限及規則也由使用者涋定。",
    "Knowledge" : "知識",
    "of how the data is stored" : "資料儲存方式",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "當資料被上傳到特定的服務提供商時，使用者應該要被告知特定的服務提供商將資料儲存在何處，該服務提供商營運多久，在哪個國家的管轄範圍內營運，以及適用何處的法律。",
    "Freedom" : "自由",
    "to choose a platform" : "選擇平台",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "使用者應該要隨時可以從服務提供者處拿回其資料，而不會遇到任何被綁在特定供應商的狀況。格式與協定的開放標準是保證這一點的必要條件。",
    "Learn more ↗" : "取得更多資訊 ↗",
    "Where is your data?" : "您的資料在哪裡？",
    "Who has access to your data?" : "誰有權存取您的資料？",
    "Administrators" : "管理員",
    "People you shared with" : "與您分享的人",
    "Privacy policy" : "隱私權政策",
    "Read the privacy policy." : "閱讀隱私權政策",
    "Encryption" : "加密",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "您的檔案已使用{linkopen}伺服器端加密 ↗{linkclose}來加密。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "您的檔案已使用{linkopen}伺服器端加密 ↗{linkclose}來加密。此外，此伺服器已由全磁碟加密保護。",
    "Your data is located in: " : "您的資料位於：",
    "The admin hasn't selected the location of the server yet." : "管理員尚未選取伺服器的位置。"
},
"nplurals=1; plural=0;");
